@@ -31,6 +31,12 @@ public abstract class SuperPage extends Page {
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
 	public abstract Page outputMain( Page from, RequestParameter req ) throws PageException;
+	/**
+	 * 初回outputの呼び出しメイン処理。
+	 * @param req リクエスト内容。
+	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 */
+	public abstract void firstOutputMain( RequestParameter req ) throws PageException;
 
 	/**
 	 * コンストラクタ。
@@ -141,6 +147,16 @@ public abstract class SuperPage extends Page {
 		return inputMain( req, fw );
 	}
 
+	/**
+	 * 初回outputの呼び出し直前にコールされます。初期化処理を記述します。
+	 * @param req リクエスト内容。
+	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+	 */
+	public void firstOutput( RequestParameter req ) throws PageException {
+		// 共通処理等あれば記述して下さい。
+		firstOutputMain( req );
+	}
+
 	/**
 	 * 出力情報の設定を行う。
 	 * @param from 遷移元ページ。直接呼ばれている場合はnullです。
