@@ -2,6 +2,7 @@
 package paraselene.mockup.output;
 
 import paraselene.*;
+import paraselene.supervisor.*;
 import paraselene.tag.*;
 import paraselene.css.*;
 import paraselene.tag.form.*;
@@ -38,6 +39,8 @@ public paraselene.Page output( paraselene.Page from, paraselene.supervisor.Reque
 public String getAliasURI() { return null; }
 public int getUploadMaxBytes(){return 0;}
 public boolean isCheckRepeatSameRequest(){ return false; }
+public AjaxSupport getAjaxSupport() { return AjaxSupport.NO; }
+public void firstOutput( RequestParameter req ) throws PageException{}
 #7
 }
 
