@@ -1,6 +1,12 @@
 // Paraselene generated this source file.
 package #1.view#2;
 
+import paraselene.*;
+import paraselene.tag.*;
+import paraselene.tag.form.*;
+import paraselene.tag.list.*;
+import paraselene.tag.table.*;
+import paraselene.css.*;
 
 /**
  * #3
@@ -22,6 +28,7 @@ try{
 #5
 }
 catch( Exception e ) {
+paraselene.supervisor.Option.debug( e );
 e.printStackTrace();
 }
 super.init();
