@@ -895,7 +895,7 @@ public abstract class Page implements Serializable {
 	 * フレームワークが使用します。ここからfirstOutputが呼ばれます。
 	 */
 	public void beginning( RequestParameter req ) throws PageException {
-		if ( !beginning_called )	return;
+		if ( beginning_called )	return;
 		beginning_called = true;
 		firstOutput( req );
 	}
