@@ -187,7 +187,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * @param enc setEncode()参照。
 	 */
 	public URIValue( URI u, String dec, String enc ) throws UnsupportedEncodingException, URISyntaxException {
-		this( encode( u.toString(), dec ), enc );
+		this( URLDecoder.decode( u.toString(), dec ), enc );
 	}
 
 	/**
@@ -226,7 +226,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * return 属性値。
 	 */
 	public URI getURI() {
-		return makeURI( super.toString() );
+		return makeURI( super.toString( StringMode.PLAIN ) );
 	}
 
 	/**
@@ -446,18 +446,16 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	public String toString( StringMode mode ) {
 		String	ret = null;
 		try {
-			ret = Supervisor.makeWithSessionURI( super.toString( StringMode.PLAIN ), getCharset() );
-		}
-		catch( NoClassDefFoundError nc ) {
-			try {
+			if ( paraselene.mockup.Linker.flag ) {
 				ret = URIValue.encode( super.toString( StringMode.PLAIN ), getCharset() );
 			}
-			catch( Exception e2 ) {
-				Option.debug( e2 );
+			else {
+				ret = Supervisor.makeWithSessionURI( super.toString( StringMode.PLAIN ), getCharset() );
 			}
 		}
-		catch( Exception e ) {
+		catch( Exception e ){
 			Option.debug( e );
+			ret = super.toString( StringMode.PLAIN );
 		}
 		if ( ret != null && mode == StringMode.CSS ) {
 			StringBuilder	buf = new StringBuilder( "url(" );
