@@ -207,7 +207,7 @@ package paraselene;
  * </tr>
  * </table>
  */
-public enum WebColor {
+public enum WebColor implements Valuable {
 	/**
 	 * BLACK
 	 */
@@ -772,7 +772,7 @@ public enum WebColor {
 	 * TRANSPARENT
 	 */
 	TRANSPARENT( 0xffffffff, 0xffffffff, 0xffffffff );
-	private static final long serialVersionUID = 1255005370014L;
+	private static final long serialVersionUID = 1256633643566L;
 	int red, green, blue;
 	private WebColor( int r, int g, int b ) {
 		red = r;green = g;blue= b;
