@@ -20,7 +20,7 @@ public abstract class Output {
 
 	static String toHtmlPath( String path ) {
 		String[]	parts = path.split( "[/\\\\]" );
-		StringBuffer	buf = new StringBuffer( parts[0] );
+		StringBuilder	buf = new StringBuilder( parts[0] );
 		for ( int i = 1; i < parts.length; i++ ) {
 			buf = buf.append( "/" );
 			buf = buf.append( parts[i] );
@@ -30,7 +30,7 @@ public abstract class Output {
 
 	static String toOSPath( String path ) {
 		String[]	parts = path.split( "[/\\\\]" );
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < parts.length; i++ ) {
 			buf = buf.append( File.separator );
 			buf = buf.append( parts[i] );
@@ -42,7 +42,7 @@ public abstract class Output {
 		if ( dir == null )	return;
 		if ( new File( dir ).exists() )	return;
 		String[]	path = dir.split( "[/\\\\]+" );
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < path.length; i++ ) {
 			buf = buf.append( path[i] );
 			buf = buf.append( File.separator );
@@ -68,7 +68,7 @@ public abstract class Output {
 
 	private static String scanLine( String str ) {
 		char[]	ch = str.toCharArray();
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < ch.length; i++ ) {
 			if ( ch[i] == '\n' || ch[i] == '\r' ) {
 				if ( i > 0 ) {
