@@ -12,7 +12,6 @@ import java.io.*;
 import java.net.*;
 import paraselene.*;
 import paraselene.tag.*;
-import paraselene.tag.attr.*;
 import paraselene.supervisor.*;
 import paraselene.dyna.*;
 
@@ -53,8 +52,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 	private HashMap<String,Integer>	method = new HashMap<String,Integer>();
 
-	private StringBuffer toName( String tag, String name ) {
-		StringBuffer	buf = new StringBuffer( " get" );
+	private StringBuilder toName( String tag, String name ) {
+		StringBuilder	buf = new StringBuilder( " get" );
 		String[]	part = name.split( "[\\p{Punct}\\p{Space}]+" );
 		for ( int i = 0; i < part.length; i++ ) {
 			if ( part[i].length() == 0 ) {
@@ -78,8 +77,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.append( "() {\n" );
 	}
 
-	private StringBuffer getCom( String name, TagSource t ) {
-		StringBuffer	buf = new StringBuffer( "/**\n" );
+	private StringBuilder getCom( String name, TagSource t ) {
+		StringBuilder	buf = new StringBuilder( "/**\n" );
 		buf = buf.append( " * " );
 		buf = buf.append( name );
 		buf = buf.append( "." );
@@ -91,8 +90,8 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.append( "\n **/\npublic " );
 	}
 
-	private StringBuffer getMethod( String name, Tag t ) throws TagException {
-		StringBuffer	buf = getCom( name, (TagSource)t );
+	private StringBuilder getMethod( String name, Tag t ) throws TagException {
+		StringBuilder	buf = getCom( name, (TagSource)t );
 		String	cls = TagMap.getClassString( t );
 		buf = buf.append( cls );
 		buf = buf.append( toName( t.getName(), name ) );
@@ -103,14 +102,14 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return buf.append( "\" );\n}\n" );
 	}
 
-	private StringBuffer getMethod( String name ) throws TagException {
+	private StringBuilder getMethod( String name ) throws TagException {
 		Tag[]	t = getAllTag( name );
 		ArrayList<Tag>	left_tag = new ArrayList<Tag>();
 		for ( int i = 0; i < t.length; i++ ) {
 			if ( Param.isIgnoreTagAccesser( t[i] ) )	continue;
 			left_tag.add( t[i] );
 		}
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		if ( left_tag.size() == 0 )	return buf;
 		t = left_tag.toArray( new Tag[0] );
 
@@ -139,7 +138,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 		case 5:
 			{
 				TagSource	tag = (TagSource)getMainTag();
-				StringBuffer	buf = new StringBuffer( tag.toSource() );
+				StringBuilder	buf = new StringBuilder( tag.toSource() );
 				buf = buf.append( "setMainTag(" );
 				buf = buf.append( tag.getValName() );
 				buf = buf.append( ");\n" );
@@ -150,7 +149,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 				buf = buf.append( Make.escape( getDoctype() ) );
 				buf = buf.append( ");\n" );
 
-				buf = buf.append( "addVersionComment(" );
+				buf = buf.append( "addVersionMeta(" );
 				buf = buf.append( Make.escape( Version.getTitle() ) );
 				buf = buf.append( "," );
 				buf = buf.append( Make.escape( new Date().toString() ) );
@@ -162,7 +161,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 			return getEnumName( true );
 		case 7:
 			{
-				StringBuffer	buf = new StringBuffer();
+				StringBuilder	buf = new StringBuilder();
 				String[]	name = getDefineNameIndex();
 				for ( int i = 0; i < name.length; i++ ) {
 					try {
@@ -177,7 +176,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 	}
 
 	String getClassName() {
-		StringBuffer	buf = new StringBuffer( Param.PACKAGE.get() );
+		StringBuilder	buf = new StringBuilder( Param.PACKAGE.get() );
 		buf = buf.append( "." );
 		buf = buf.append( out_dir[1] );
 		if ( package_name.length() > 0 ) {
@@ -190,7 +189,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 	String getEnumName( boolean only_f ) {
 		if ( only_f )	return enum_name;
-		StringBuffer	buf = new StringBuffer( Param.PACKAGE.get() );
+		StringBuilder	buf = new StringBuilder( Param.PACKAGE.get() );
 		buf = buf.append( ".base.PageType." );
 		buf = buf.append( enum_name );
 		return buf.toString();
@@ -198,7 +197,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 	void makeSourceMain( int dir, Output output ) throws Exception {
 		Linker.readme.setCurrentPage( this );
-		StringBuffer	out_path = new StringBuffer( Make.SRC_PATH );
+		StringBuilder	out_path = new StringBuilder( Make.SRC_PATH );
 		out_path = out_path.append( File.separator );
 		out_path = out_path.append( out_dir[dir] );
 		out_path = out_path.append( File.separator );
@@ -252,7 +251,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 	}
 
 	String getNote() {
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		int	cnt = note.size();
 		for ( int i = 0; i < cnt; i++ ) {
 			buf = buf.append( note.get( i ) );
@@ -334,7 +333,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 		class_name = tmp.getName().toLowerCase( Locale.ENGLISH );
 		String[]	part = class_name.split( "[\\p{Punct}\\p{Space}]+" );
-		StringBuffer	buf = new StringBuffer();
+		StringBuilder	buf = new StringBuilder();
 		for ( int i = 0; i < part.length; i++ ) {
 			ch = part[i].toCharArray();
 			ch[0] = Character.toUpperCase( ch[0] );
@@ -342,7 +341,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 		}
 		class_name = buf.toString();
 
-		buf = new StringBuffer( enum_name );
+		buf = new StringBuilder( enum_name );
 		enum_name = tmp.getName().toUpperCase();
 		part = enum_name.split( "[\\p{Punct}\\p{Space}]+" );
 		for ( int i = 0; i < part.length; i++ ) {
@@ -377,7 +376,7 @@ public class PrePage extends DynamicPage implements OutputNo {
 	}
 
 	private PrePage( Page p ) {
-		super( Boolean.valueOf( Param.NEKO.get() ), null, p, Param.provider );
+		super( null, p, Param.provider );
 	}
 
 	PrePage( File p )
@@ -389,13 +388,13 @@ public class PrePage extends DynamicPage implements OutputNo {
 	PrePage( File p, boolean dev_f )
 	throws FileNotFoundException, UnsupportedEncodingException, IOException,
 	DynamicPageException {
-		super( Boolean.valueOf( Param.NEKO.get() ), null, Param.provider );
+		super( null, Param.provider );
 		path = p.getPath();
 		html_last_time = p.lastModified();
 		if ( !dev_f )	init();
 		if ( this instanceof Download )	return;
 
-		StringBuffer	out_path = new StringBuffer( Make.SRC_PATH );
+		StringBuilder	out_path = new StringBuilder( Make.SRC_PATH );
 		out_path = out_path.append( File.separator );
 		out_path = out_path.append( out_dir[0] );
 		out_path = out_path.append( File.separator );
@@ -404,6 +403,9 @@ public class PrePage extends DynamicPage implements OutputNo {
 
 		Linker.readme.setCurrentPage( this );
 		create( p, Param.IN_ENCODE.get() );
+		if ( !isXML() && getParsingCharset() == null ) {
+			addNote( "警告: 解析時にHTMLの文字コードを決定できませんでした。" );
+		}
 	}
 
 	public PageID getID() { return new PrePageID( id ); }
@@ -441,15 +443,11 @@ public class PrePage extends DynamicPage implements OutputNo {
 		return nt;
 	}
 
-	protected Comment makeComment( String str ) {
-		return new CommentSource( str );
-	}
-
 	protected Text makeText( String str ) {
 		return new TextSource( str );
 	}
 
-	protected boolean isRuntime() {
+	public boolean isRuntime() {
 		return false;
 	}
 }
