@@ -77,6 +77,8 @@ class TagSource extends Tag implements Source {
 		else if ( Converter.isStyle( name ) ) {
 			buf = buf.append( "new Style(Property.create(" );
 			buf = buf.append( Make.escape( val ) );
+			buf = buf.append( "," );
+			buf = buf.append( Make.escape( ((PrePage)embed).getParsingCharset() ) );
 			buf = buf.append( ")))" );
 			return buf.toString();
 		}
