@@ -8,6 +8,7 @@
 package paraselene.mockup.output;
 
 import paraselene.*;
+import paraselene.supervisor.*;
 import paraselene.tag.*;
 import paraselene.css.*;
 import paraselene.tag.form.*;
@@ -226,7 +227,7 @@ tag127.addHTMLPart(text308);
 Form tag200=new Form();
 tag200.setAttribute(new Attribute("name",new Text("uri_form")));
 SingleTextBox tag201=new SingleTextBox(false);
-tag201.setAttribute(new Attribute("style",new Style(Property.create("background-color :yellow;"))),new Attribute("name",new Text("url")),new Attribute("value",new Text("http://")),new Attribute("type",new Text("text")),new Attribute("size",new NumberValue("60")));
+tag201.setAttribute(new Attribute("style",new Style(Property.create("background-color :#FFFF00;","UTF-8"))),new Attribute("name",new Text("url")),new Attribute("value",new Text("http://")),new Attribute("type",new Text("text")),new Attribute("size",new NumberValue("60")));
 tag200.addHTMLPart(tag201);
 Text text280=new Text("\n例えばここに、http://localhost:8080/test/ と予め入力しておき、logicクラス一覧の");
 tag200.addHTMLPart(text280);
@@ -352,7 +353,7 @@ tag127.addHTMLPart(tag228);
 tag120.addHTMLPart(tag127);
 setMainTag(tag120);
 setDoctype(false,null);
-addVersionMeta("Paraselene 2.0.0 (http://paraselene.sourceforge.jp/)","Sun Nov 01 10:23:05 JST 2009");
+addVersionMeta("Paraselene 2.0.1 (http://paraselene.sourceforge.jp/)","Tue Nov 03 15:36:17 JST 2009");
 
 }
 catch(Exception e){}
@@ -373,6 +374,8 @@ public paraselene.Page output( paraselene.Page from, paraselene.supervisor.Reque
 public String getAliasURI() { return null; }
 public int getUploadMaxBytes(){return 0;}
 public boolean isCheckRepeatSameRequest(){ return false; }
+public AjaxSupport getAjaxSupport() { return AjaxSupport.NO; }
+public void firstOutput( RequestParameter req ) throws PageException{}
 /**
  * ex.
  **/
@@ -433,7 +436,7 @@ return getAllTag( "root" );
 }
 /**
  * uri_form.
- * <br>&lt;form&nbsp;id=&quot;paraselene$id$7nx4ftfrn4pm&quot;&nbsp;name=&quot;uri_form&quot;&gt;
+ * <br>&lt;form&nbsp;id=&quot;paraselene$id$4xdl0gyuiuem&quot;&nbsp;name=&quot;uri_form&quot;&gt;
  **/
 public Form getUriFormForm() {
 return (Form)getTag( "uri_form" );
@@ -459,7 +462,7 @@ return getAllTag( "echo" );
 }
 /**
  * url.
- * <br>&lt;input&nbsp;style=&quot;background-color&nbsp;:yellow;&quot;&nbsp;name=&quot;url&quot;&nbsp;value=&quot;http://&quot;&nbsp;type=&quot;text&quot;&nbsp;size=&quot;60&quot;&gt;
+ * <br>&lt;input&nbsp;style=&quot;background-color&nbsp;:#FFFF00;&quot;&nbsp;name=&quot;url&quot;&nbsp;value=&quot;http://&quot;&nbsp;type=&quot;text&quot;&nbsp;size=&quot;60&quot;&gt;
  **/
 public SingleTextBox getUrlInput() {
 return (SingleTextBox)getTag( "url" );
